##  Aggregation of Process Template and Variants
Separate fact sheets are not created for process variants. For each process template, a corresponding business context fact sheet is created after aggregating process templates and their variants.
